-------
cerebro
-------

|CircleCI| |codecov| |codacy| |codeclimate| |pypiversion|

Core engine for @LeBot, A generic bot that will be able to do custom tasks on the basis of the
interaction with User.

Run Tests
=========
::

  nosetests

Run Start
=========

::

  python start.py <command>


List of supported Commands
==========================

::

  "how are you?", "what is the time?", "what is the date?"

.. |CircleCI| image:: https://circleci.com/gh/Le-Bot/cerebro/tree/master.svg?style=shield
   :target: https://circleci.com/gh/Le-Bot/cerebro/tree/master
.. |codecov| image:: https://codecov.io/gh/Le-Bot/cerebro/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/Le-Bot/cerebro
.. |pypiversion| image:: https://badge.fury.io/py/lebot-cerebro.svg
   :target: https://badge.fury.io/py/lebot-cerebro
.. |codeclimate| image:: https://codeclimate.com/github/Le-Bot/cerebro/badges/gpa.svg
   :target: https://codeclimate.com/github/Le-Bot/cerebro
.. |codacy| image:: https://api.codacy.com/project/badge/Grade/290492beb84f4f63818d753a1c98288c
   :target: https://www.codacy.com/app/Le-Bot/cerebro?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Le-Bot/cerebro&amp;utm_campaign=Badge_Grade